/**
 * Copyright (C) 2010-2011 enStratusNetworks LLC
 *
 * ====================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ====================================================================
 */

package org.dasein.cloud.metacdn;

import org.apache.log4j.Logger;
import org.dasein.cloud.AbstractCloud;
import org.dasein.cloud.metacdn.platform.MetaCDNPlatformServices;

public class MetaCDN extends AbstractCloud {
	static private final Logger logger = Logger.getLogger(MetaCDN.class);

    public MetaCDN() { }
    
    @Override
    public String getCloudName() {
        return "MetaCDN";
    }

    @Override
    public MetaCDNPlatformServices getPlatformServices() {
        return new MetaCDNPlatformServices(this);
    }
    
    @Override
    public String getProviderName() {
        return "MetaCDN";
    }

    public byte[] getAuthorization() {
    	StringBuilder sb = new StringBuilder(getContext().getAccountNumber());
    	sb.append(":");
    	sb.append(getContext().getStoragePrivate());
    	System.out.println(sb.toString());
    	return sb.toString().getBytes();
    }
    
    public String getProxyHost() {
	    return getContext().getCustomProperties().getProperty("proxyHost");
	}
	
	public int getProxyPort() {
	    String port = getContext().getCustomProperties().getProperty("proxyPort");
	    
	    if( port != null ) {
	        return Integer.parseInt(port);
	    }
	    return -1;
	}
    
	@Override
	public String testContext() {
	    try {
	        if( getPlatformServices().getCDNSupport().isSubscribed() ) {
	            return getContext().getAccountNumber();
	        }
	    }
	    catch( Throwable t ) {
	        logger.warn("Unable to test MetaCDN context: " + t.getMessage());
	        if( logger.isDebugEnabled() ) {
	            t.printStackTrace();
	        }
	    }
	    return null;
	}
}
